| Title: | Provide Tours of 'Shiny' Applications |
|---|---|
| Description: | Provide step by step guided tours of 'Shiny' applications. |
| Authors: | John Coene [aut, cre] (ORCID: <https://orcid.org/0000-0002-6637-4107>), Etienne Bacher [ctb], Stephen Holsenbeck [ctb] |
| Maintainer: | John Coene <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.5.9000 |
| Built: | 2026-05-09 06:19:53 UTC |
| Source: | https://github.com/johncoene/cicerone |
Define cicerone steps.
left
right
left-center
left-bottom
top
top-center
top-right
right
right-center
right-bottom
bottom
bottom-center
mid-center
new()
Cicerone$new( animate = TRUE, opacity = 0.75, padding = 10, allow_close = TRUE, overlay_click_next = FALSE, done_btn_text = "Done", close_btn_text = "Close", stage_background = "#ffffff", next_btn_text = "Next", prev_btn_text = "Previous", show_btns = TRUE, keyboard_control = TRUE, id = NULL, mathjax = FALSE )
animateWhether to animate or not.
opacityBackground opacity (0 means only popovers and without overlay).
paddingDistance of element from around the edges.
allow_closeWhether the click on overlay should close or not.
overlay_click_nextWhether the click on overlay should move next.
done_btn_textText on the final button.
close_btn_textText on the close button for this step.
stage_backgroundBackground color for the staged behind highlighted element.
next_btn_textNext button text for this step.
prev_btn_textPrevious button text for this step.
show_btnsDo not show control buttons in footer.
keyboard_controlAllow controlling through keyboard (escape to close, arrow keys to move).
idA unique identifier, useful if you are using more than one cicerone.
mathjaxWhether to use MathJax in the steps.
Create a new Cicerone object.
A Cicerone object.
step()
Cicerone$step( el, title = NULL, description = NULL, position = NULL, class = NULL, show_btns = NULL, close_btn_text = NULL, next_btn_text = NULL, prev_btn_text = NULL, tab = NULL, tab_id = NULL, is_id = NULL, on_highlighted = NULL, on_highlight_started = NULL, on_next = NULL )
elId of element to be highlighted.
titleTitle on the popover.
descriptionBody of the popover.
positionWhere to position the popover. See positions section.
classclassName to wrap this specific step popover in addition to the general className in Driver options.
show_btnsWhether to show control buttons.
close_btn_textText on the close button.
next_btn_textNext button text.
prev_btn_textPrevious button text.
tabThe name of the tab to set.
tab_idThe id of the tabs to activate in order to highlight tab_id.
is_idDeprecated Whether the selector passed to el is an HTML id, set to FALSE to use
other selectors, e.g.: .class.
on_highlightedA JavaScript function to run when the step is highlighted, generally a callback function. This is effectively a string that is evaluated JavaScript-side.
on_highlight_startedA JavaScript function to run when the step is just aobut to be highlighted, generally a callback function. This is effectively a string that is evaluated JavaScript-side.
on_nextA JavaScript function to run when the next button is clicked (or its event triggered), generally a callback function. This is effectively a string that is evaluated JavaScript-side.
Add a step.
init()
Cicerone$init(session = NULL, run_once = FALSE)
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
run_onceWhether to only run the guide once. If TRUE
any subsequent calls of the method will not run the guide.
Initialise Cicerone.
reset()
Cicerone$reset(session = NULL)
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
Reset Cicerone.
start()
Cicerone$start(step = 1, session = NULL)
stepThe step index at which to start.
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
Start Cicerone.
move_forward()
Cicerone$move_forward(session = NULL)
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
Move Cicerone one step.
move_backward()
Cicerone$move_backward(session = NULL)
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
Move Cicerone one step backward.
highlight()
Cicerone$highlight(el, session = NULL)
elId of element to highlight
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
Highlight a specific step.
get_highlighted_el()
Cicerone$get_highlighted_el(session = NULL)
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
Retrieve the id of the currently highlighted element.
get_previous_el()
Cicerone$get_previous_el(session = NULL)
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
Retrieve the id of the previously highlighted element.
has_next_step()
Cicerone$has_next_step(session = NULL)
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
Retrieve whether there is a next step.
get_next()
Cicerone$get_next(session = NULL)
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
Retrieve data that was fired when the user hit the "next" button.
get_previous()
Cicerone$get_previous(session = NULL)
sessionA valid Shiny session if NULL the function
attempts to get the session with shiny::getDefaultReactiveDomain().
Retrieve data that was fired when the user hit the "previous" button.
clone()
The objects of this class are cloneable with this method.
Cicerone$clone(deep = FALSE)
deepWhether to make a deep clone.
Initialise and highlight an element.
highlight( el, id, title = NULL, description = NULL, position = NULL, class = NULL, show_btns = NULL, close_btn_text = NULL, next_btn_text = NULL, prev_btn_text = NULL, session = NULL ) initialise( id, animate = TRUE, opacity = 0.75, padding = 10, allow_close = TRUE, overlay_click_next = FALSE, done_btn_text = "Done", close_btn_text = "Close", stage_background = "#ffffff", next_btn_text = "Next", prev_btn_text = "Previous", show_btns = TRUE, keyboard_control = TRUE, session = NULL )highlight( el, id, title = NULL, description = NULL, position = NULL, class = NULL, show_btns = NULL, close_btn_text = NULL, next_btn_text = NULL, prev_btn_text = NULL, session = NULL ) initialise( id, animate = TRUE, opacity = 0.75, padding = 10, allow_close = TRUE, overlay_click_next = FALSE, done_btn_text = "Done", close_btn_text = "Close", stage_background = "#ffffff", next_btn_text = "Next", prev_btn_text = "Previous", show_btns = TRUE, keyboard_control = TRUE, session = NULL )
el |
Id of element to be highlighted. |
id |
Unique identifier of cicerone. |
title |
Title on the popover. |
description |
Body of the popover. |
position |
Where to position the popover. See positions section. |
class |
className to wrap this specific step popover in addition to the general className in Driver options. |
show_btns |
Do not show control buttons in footer. |
close_btn_text |
Text on the close button for this step. |
next_btn_text |
Next button text for this step. |
prev_btn_text |
Previous button text for this step. |
session |
A valid Shiny session if |
animate |
Whether to animate or not. |
opacity |
Background opacity (0 means only popovers and without overlay). |
padding |
Distance of element from around the edges. |
allow_close |
Whether the click on overlay should close or not. |
overlay_click_next |
Whether the click on overlay should move next. |
done_btn_text |
Text on the final button. |
stage_background |
Background color for the staged behind highlighted element. |
keyboard_control |
Allow controlling through keyboard (escape to close, arrow keys to move). |
left
right
left-center
left-bottom
top
top-center
top-right
right
right-center
right-bottom
bottom
bottom-center
mid-center
Include cicerone dependencies in your Shiny UI.
use_cicerone()use_cicerone()
library(shiny) ui <- fluidPage( use_cicerone() ) server <- function(input, output){} if(interactive()) shinyApp(ui, server)library(shiny) ui <- fluidPage( use_cicerone() ) server <- function(input, output){} if(interactive()) shinyApp(ui, server)